@@ -23,6 +23,7 @@
 import shlex
 import subprocess
 import time
+import numbers
 import unittest
 
 from glances import __version__
@@ -55,8 +56,8 @@ class TestGlances(unittest.TestCase):
         print("Run the Glances Web Server on port %s" % SERVER_PORT)
         args = shlex.split(cmdline)
         pid = subprocess.Popen(args)
-        print("Please wait...")
-        time.sleep(3)
+        print("Please wait 5 seconds...")
+        time.sleep(5)
 
         self.assertTrue(pid is not None)
 
@@ -92,8 +93,8 @@ class TestGlances(unittest.TestCase):
             self.assertTrue(req.ok)
             if p in ('uptime', 'now'):
                 self.assertIsInstance(req.json(), text_type)
-            elif p in ('fs', 'monitor', 'percpu', 'sensors', 'alert', 'processlist',
-                       'diskio', 'hddtemp', 'batpercent', 'network', 'folders'):
+            elif p in ('fs', 'percpu', 'sensors', 'alert', 'processlist', 'diskio',
+                       'hddtemp', 'batpercent', 'network', 'folders', 'amps', 'ports', 'irq'):
                 self.assertIsInstance(req.json(), list)
             elif p in ('psutilversion', 'help'):
                 pass
@@ -111,7 +112,8 @@ class TestGlances(unittest.TestCase):
             req = requests.get("%s/%s/%s" % (URL, method, i))
             self.assertTrue(req.ok)
             self.assertIsInstance(req.json(), dict)
-            self.assertIsInstance(req.json()[i], float)
+            print(req.json()[i])
+            self.assertIsInstance(req.json()[i], numbers.Number)
 
     def test_005_values(self):
         """Values."""
@@ -167,6 +169,31 @@ class TestGlances(unittest.TestCase):
             self.assertTrue(req.ok)
             self.assertIsInstance(req.json(), dict)
 
+    def test_010_history(self):
+        """History."""
+        method = "history"
+        print('INFO: [TEST_010] History')
+        print("HTTP RESTful request: %s/cpu/%s" % (URL, method))
+        req = requests.get("%s/cpu/%s" % (URL, method))
+        self.assertIsInstance(req.json(), dict)
+        self.assertIsInstance(req.json()['user'], list)
+        self.assertTrue(len(req.json()['user']) > 0)
+        print("HTTP RESTful request: %s/cpu/%s/3" % (URL, method))
+        req = requests.get("%s/cpu/%s/3" % (URL, method))
+        self.assertIsInstance(req.json(), dict)
+        self.assertIsInstance(req.json()['user'], list)
+        self.assertTrue(len(req.json()['user']) == 3)
+        print("HTTP RESTful request: %s/cpu/system/%s" % (URL, method))
+        req = requests.get("%s/cpu/system/%s" % (URL, method))
+        self.assertIsInstance(req.json(), dict)
+        self.assertIsInstance(req.json()['system'], list)
+        self.assertTrue(len(req.json()['system']) > 0)
+        print("HTTP RESTful request: %s/cpu/system/%s/3" % (URL, method))
+        req = requests.get("%s/cpu/system/%s/3" % (URL, method))
+        self.assertIsInstance(req.json(), dict)
+        self.assertIsInstance(req.json()['system'], list)
+        self.assertTrue(len(req.json()['system']) == 3)
+
     def test_999_stop_server(self):
         """Stop the Glances Web Server."""
         print('INFO: [TEST_999] Stop the Glances Web Server')
